@@ -684,3 +684,36 @@ test!(
     []
     "#
 );
+
+test!(
+    input,
+    r#"
+    [., input]
+    "#,
+    r#"
+    1
+    2
+    3
+    4
+    "#,
+    r#"
+    [1, 2]
+    [3, 4]
+    "#
+);
+
+test!(
+    inputs,
+    r#"
+    [., inputs]
+    "#,
+    r#"
+    1
+    2
+    3
+    4
+    "#,
+    r#"
+    [1, 2, 3, 4]
+    "#
+);
